@@ -121,13 +121,19 @@ class StatisticalHelperMethods:
     
     @staticmethod
     def precise_beta(a: float, b: float) -> Decimal:
+        
         precise_beta_function = lambda a,b: (StatisticalHelperMethods.precise_gamma(a)*StatisticalHelperMethods.precise_gamma(b))/(StatisticalHelperMethods.precise_gamma(a+b))
         try:
+            print("Running precise beta: {}, {}".format(a,b))
             return precise_beta_function(a,b)
         except decimal.Overflow:
+            print("Decimal overflow thrown at precise beta function with B({},{})".format(a,b))
+
+            new_precision = decimal.getcontext().prec*2 if decimal.getcontext().prec * 2 > 1000 else 1000
             print("Decimal overflow thrown - attempting calculatin with doubled the precision from {} to {}".format(decimal.getcontext().prec, decimal.getcontext().prec*2))
+            
             with decimal.localcontext() as ctx:
-                ctx.prec *= 2  # increase the precision by 10
+                ctx.prec = new_precision  # increase the precision
                 return precise_beta_function(a,b)
 
 
@@ -205,11 +211,14 @@ def perform_singleton_score_imputation(each_guide: Guide,
     singleton_imputation_prior_strength: List[float],
     replicate_indices: List[int]) -> Tuple[List[float], List[float]]:
     
-    imputation_posterior_alpha = (singleton_imputation_prior_strength*negative_control_guide_pop1_total_normalized_counts_reps[replicate_indices]) 
+    imputation_posterior_alpha = singleton_imputation_prior_strength*negative_control_guide_pop1_total_normalized_counts_reps[replicate_indices]
     
-    imputation_posterior_beta = (singleton_imputation_prior_strength*negative_control_guide_pop2_total_normalized_counts_reps[replicate_indices])
+    imputation_posterior_beta = singleton_imputation_prior_strength*negative_control_guide_pop2_total_normalized_counts_reps[replicate_indices]
 
-    max_imputation_posterior = 5000 # Setting this max, since calculating the KL divergence of a very high posterior value will result in a precision error
+    imputation_posterior_alpha = imputation_posterior_alpha.astype(int)
+    imputation_posterior_beta = imputation_posterior_beta.astype(int)
+
+    max_imputation_posterior = 1000 # Setting this max, since calculating the KL divergence of a very high posterior value will result in a precision error
     for rep_i in range(len(replicate_indices)):
         if max(imputation_posterior_alpha[rep_i],imputation_posterior_beta[rep_i]) > max_imputation_posterior:
             print("Downscaling posterior: {}, {}".format(imputation_posterior_alpha[rep_i],imputation_posterior_beta[rep_i]))
